@@ -1,8 +1,13 @@
 {% include "apps/openedx/settings/partials/common_all.py" %}
 
 ######## Common CMS settings
+STUDIO_NAME = "{{ PLATFORM_NAME }} - Studio"
 
-STUDIO_NAME = u"{{ PLATFORM_NAME }} - Studio"
+CACHES["staticfiles"] = {
+    "KEY_PREFIX": "staticfiles_cms",
+    "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+    "LOCATION": "staticfiles_cms",
+}
 
 # Authentication
 SOCIAL_AUTH_EDX_OAUTH2_SECRET = "{{ CMS_OAUTH2_SECRET }}"
@@ -13,7 +18,6 @@ SESSION_COOKIE_NAME = "studio_session_id"
 MAX_ASSET_UPLOAD_FILE_SIZE_IN_MB = 100
 
 FRONTEND_LOGIN_URL = LMS_ROOT_URL + '/login'
-FRONTEND_LOGOUT_URL = LMS_ROOT_URL + '/logout'
 FRONTEND_REGISTER_URL = LMS_ROOT_URL + '/register'
 
 # Create folders if necessary
